import { Transport, TransportOpts, MetadataCallback } from './transport';
import { CredentialedActionShape, PlayerID, State } from '../../types';
interface SocketIOOpts {
    server?: string;
    socketOpts?: any;
}
declare type SocketIOTransportOpts = TransportOpts & SocketIOOpts & {
    socket?: any;
};
/**
 * SocketIO
 *
 * Transport interface that interacts with the Master via socket.io.
 */
export declare class SocketIOTransport extends Transport {
    server: string;
    socket: any;
    socketOpts: any;
    callback: () => void;
    matchDataCallback: MetadataCallback;
    /**
     * Creates a new Mutiplayer instance.
     * @param {object} socket - Override for unit tests.
     * @param {object} socketOpts - Options to pass to socket.io.
     * @param {string} matchID - The game ID to connect to.
     * @param {string} playerID - The player ID associated with this client.
     * @param {string} gameName - The game type (the `name` field in `Game`).
     * @param {string} numPlayers - The number of players.
     * @param {string} server - The game server in the form of 'hostname:port'. Defaults to the server serving the client if not provided.
     */
    constructor({ socket, socketOpts, store, matchID, playerID, gameName, numPlayers, server, }?: SocketIOTransportOpts);
    /**
     * Called when an action that has to be relayed to the
     * game master is made.
     */
    onAction(state: State, action: CredentialedActionShape.Any): void;
    /**
     * Connect to the server.
     */
    connect(): void;
    /**
     * Disconnect from the server.
     */
    disconnect(): void;
    /**
     * Subscribe to connection state changes.
     */
    subscribe(fn: () => void): void;
    subscribeMatchData(fn: MetadataCallback): void;
    /**
     * Updates the game id.
     * @param {string} id - The new game id.
     */
    updateMatchID(id: string): void;
    /**
     * Updates the player associated with this client.
     * @param {string} id - The new player id.
     */
    updatePlayerID(id: PlayerID): void;
}
export declare function SocketIO({ server, socketOpts }?: SocketIOOpts): (transportOpts: SocketIOTransportOpts) => SocketIOTransport;
export {};
